==> ui-hub-0.0.1.tgz: package/es/drawer/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import ReactDOM from 'react-dom';
import PortalFactory from '../portal-factory/index';
import BaseDrawer from './drawer'; // Feature 是否存在更好的实现方式，如Symbol

var closeFnCallFlag = '@@__symbols__fromCloseFn_';

var renderDrawer = function renderDrawer(props, update, destroy) {
  var content = props.content,
      onHide = props.onHide,
      onCancel = props.onCancel,
      restProps = _objectWithoutProperties(props, ["content", "onHide", "onCancel"]);

  var isInClosing = !!props[closeFnCallFlag];
  delete restProps[closeFnCallFlag];

  var close = function close() {
    var _objectSpread2;

    if (isInClosing) {
      return;
    }

    var newProps = _objectSpread(_objectSpread({}, props), {}, (_objectSpread2 = {}, _defineProperty(_objectSpread2, closeFnCallFlag, true), _defineProperty(_objectSpread2, "visible", false), _objectSpread2));

    update(newProps);
  };

  var onCancelFn = function onCancelFn() {
    for (var _len = arguments.length, customParam = new Array(_len), _key = 0; _key < _len; _key++) {
      customParam[_key] = arguments[_key];
    }

    typeof onCancel === 'function' ? onCancel.apply(void 0, [close].concat(customParam)) : close();
  };

  var onHideFn = function onHideFn() {
    typeof onHide === 'function' && onHide(); // 可以通过控制 show 参数来触发 onHide 回调，下面的
    // 这个判断本意是区分是由内部的关闭函数引发的还是show
    // 参数的改变引发的，但是这个方法中并没有暴露出修改props
    // 的接口, 因此可以去掉这个判断.
    // if (isInClosing) {
    // }

    destroy();
  };

  return /*#__PURE__*/React.createElement(BaseDrawer, _extends({}, restProps, {
    onCancel: onCancelFn,
    onHide: onHideFn
  }), content);
};

var Drawer = function Drawer(props) {
  return /*#__PURE__*/ReactDOM.createPortal( /*#__PURE__*/React.createElement(BaseDrawer, props), document.body);
};

Drawer.createDrawer = function (config) {
  var props = _objectSpread({}, config);

  var pf = PortalFactory(renderDrawer);
  pf.render(props);
};

export default Drawer;

==> ui-hub-0.0.6.tgz: package/es/drawer/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import ReactDOM from 'react-dom';
import PortalFactory from '../portal-factory/index';
import BaseDrawer from './drawer';
// Feature 是否存在更好的实现方式，如Symbol
var closeFnCallFlag = '@@__symbols__fromCloseFn_';

var renderDrawer = function renderDrawer(props, update, destroy) {
  var content = props.content,
      onHide = props.onHide,
      onCancel = props.onCancel,
      restProps = _objectWithoutProperties(props, ["content", "onHide", "onCancel"]);

  var isInClosing = !!props[closeFnCallFlag];
  delete restProps[closeFnCallFlag];

  var close = function close() {
    var _objectSpread2;

    if (isInClosing) {
      return;
    }

    var newProps = _objectSpread(_objectSpread({}, props), {}, (_objectSpread2 = {}, _defineProperty(_objectSpread2, closeFnCallFlag, true), _defineProperty(_objectSpread2, "visible", false), _objectSpread2));

    update(newProps);
  };

  var onCancelFn = function onCancelFn() {
    for (var _len = arguments.length, customParam = new Array(_len), _key = 0; _key < _len; _key++) {
      customParam[_key] = arguments[_key];
    }

    typeof onCancel === 'function' ? onCancel.apply(void 0, [close].concat(customParam)) : close();
  };

  var onHideFn = function onHideFn() {
    typeof onHide === 'function' && onHide(); // 可以通过控制 show 参数来触发 onHide 回调，下面的
    // 这个判断本意是区分是由内部的关闭函数引发的还是show
    // 参数的改变引发的，但是这个方法中并没有暴露出修改props
    // 的接口, 因此可以去掉这个判断.
    // if (isInClosing) {
    // }

    destroy();
  };

  return /*#__PURE__*/React.createElement(BaseDrawer, _extends({}, restProps, {
    onCancel: onCancelFn,
    onHide: onHideFn
  }), content);
};

var Drawer = function Drawer(props) {
  return /*#__PURE__*/ReactDOM.createPortal( /*#__PURE__*/React.createElement(BaseDrawer, props), document.body);
};

Drawer.createDrawer = function (config) {
  var props = _objectSpread({}, config);

  var pf = PortalFactory(renderDrawer);
  pf.render(props);
};

export default Drawer;
